pub struct BitrateAllocationLimits {
pub min_allocatable_rate: DataRate,
pub max_allocatable_rate: DataRate,
pub max_padding_rate: DataRate,
}Expand description
Represents constraints and rates related to the currently enabled streams. This is used as input to the congestion controller via the StreamsConfig struct.
Fields
min_allocatable_rate: DataRatemax_allocatable_rate: DataRatemax_padding_rate: DataRateTrait Implementations
Sourceimpl Clone for BitrateAllocationLimits
impl Clone for BitrateAllocationLimits
Sourcefn clone(&self) -> BitrateAllocationLimits
fn clone(&self) -> BitrateAllocationLimits
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BitrateAllocationLimits
impl Debug for BitrateAllocationLimits
Sourceimpl Default for BitrateAllocationLimits
impl Default for BitrateAllocationLimits
Sourcefn default() -> BitrateAllocationLimits
fn default() -> BitrateAllocationLimits
Returns the “default value” for a type. Read more
impl Copy for BitrateAllocationLimits